==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/lhcsmapi/analysis/IpqCircuitQuery.py <==
import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.busbar.BusbarResistanceQuery import BusbarResistanceQuery
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.pc.PcQuery import PcItQuery
from lhcsmapi.analysis.pic.PicQuery import PicQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsIpdQuery
from lhcsmapi.analysis.qh.QuenchHeaterQuery import QuenchHeaterQuery
from lhcsmapi.analysis.CircuitQuery import CircuitQuery
from lhcsmapi.metadata.SignalMetadata import SignalMetadata

from lhcsmapi.reference.Reference import Reference


class IpqCircuitQuery(PicQuery, PcItQuery, QuenchHeaterQuery, QdsIpdQuery, DfbQuery, BusbarResistanceQuery,
                      CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables in IPQ circuits.

    """

    def __init__(self, circuit_type, circuit_name, max_executions=None, verbose=True):
        super().__init__(circuit_type, circuit_name, max_executions, verbose)

        if self.circuit_name in SignalMetadata.get_circuit_names('IPQ2'):
            self.circuit_type = 'IPQ2'
        elif self.circuit_name in SignalMetadata.get_circuit_names('IPQ4'):
            self.circuit_type = 'IPQ4'
        elif self.circuit_name in SignalMetadata.get_circuit_names('IPQ8'):
            self.circuit_type = 'IPQ8'
        else:
            raise ValueError('Circuit name %s does not map to internal IPQ metadata.' % self.circuit_name)

    def create_report_analysis_template(self, timestamp_fgc: int, init_file_path: str, author='') -> pd.DataFrame:
        """ Method creating a report analysis template for IPQ circuits

        :param timestamp_fgc: timestamp of an FGC event
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be completed further with data from an analysis of
            a powering event in IPQ circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='IPQ', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_name.split('.')[0]
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC_Bn)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC_Bn)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table

==> lhcsmapi-1.5.13.tar.gz: lhcsmapi-1.5.13/lhcsmapi/analysis/IpqCircuitQuery.py <==
import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.busbar.BusbarResistanceQuery import BusbarResistanceQuery
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.pc.PcQuery import PcItQuery
from lhcsmapi.analysis.pic.PicQuery import PicQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsIpdQuery
from lhcsmapi.analysis.qh.QuenchHeaterQuery import QuenchHeaterQuery
from lhcsmapi.analysis.CircuitQuery import CircuitQuery
from lhcsmapi.metadata.MappingMetadata import MappingMetadata
from lhcsmapi.metadata.SignalMetadata import SignalMetadata

from lhcsmapi.reference.Reference import Reference


class IpqCircuitQuery(PicQuery, PcItQuery, QuenchHeaterQuery, QdsIpdQuery, DfbQuery, BusbarResistanceQuery,
                      CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables in IPQ circuits.

    """

    def __init__(self, circuit_type, circuit_name, max_executions=None, verbose=True):
        super().__init__(circuit_type, circuit_name, max_executions, verbose)

        self.circuit_type = SignalMetadata.get_circuit_type_for_circuit_name(circuit_name)

    @staticmethod
    def get_circuit_name_to_earth_measurement_dataframe(circuit_type: str, circuit_name:str) -> pd.DataFrame:
        """ Method returning a DataFrame with information on power converter with earth current measurement:
        - B1
        - B2
        - B1 and B2

        Based on https://edms.cern.ch/document/2359699/1

        :param circuit_type: circuit type
        :type circuit_type: str
        :param circuit_name: circuit name
        :type circuit_name: str
        :return: QPS schematic name
        """

        return MappingMetadata.get_circuit_name_to_earth_measurement_dataframe(circuit_type, circuit_name)

    def create_report_analysis_template(self, timestamp_fgc: int, init_file_path: str, author='') -> pd.DataFrame:
        """ Method creating a report analysis template for IPQ circuits

        :param timestamp_fgc: timestamp of an FGC event
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be completed further with data from an analysis of
            a powering event in IPQ circuits
        """
        columns = Reference.read_quench_database_columns(circuit_type='IPQ', table_type='MP3')

        results_table = pd.DataFrame(columns=columns, index=[0])
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_name.split('.')[0]
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC_Bn)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC_Bn)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        return results_table
